summaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
Diffstat (limited to 'scripts')
-rw-r--r--scripts/find-debuginfo.sh14
-rwxr-xr-xscripts/find-provides.php2
-rwxr-xr-xscripts/find-requires.php6
-rw-r--r--scripts/mono-find-provides2
-rw-r--r--scripts/mono-find-requires2
-rwxr-xr-xscripts/vpkg-provides.sh10
6 files changed, 18 insertions, 18 deletions
diff --git a/scripts/find-provides.php b/scripts/find-provides.php
index 11178bf37..4e6a03d01 100755
--- a/scripts/find-provides.php
+++ b/scripts/find-provides.php
@@ -8,7 +8,7 @@ filelist=`echo $@`
for i in $filelist; do
i=`echo $i | grep "\.php$"`
if [ -n "$i" ]; then
- j=`cat $i |egrep -i "^Class" |cut -f 2 -d " "| tr -d "\r"`
+ j=`cat $i |grep -E -i "^Class" |cut -f 2 -d " "| tr -d "\r"`
if [ -n "$j" ]; then
for p in $j; do
echo "pear($p)"
diff --git a/scripts/find-requires.php b/scripts/find-requires.php
index 203aefbc8..4c064fcff 100755
--- a/scripts/find-requires.php
+++ b/scripts/find-requires.php
@@ -18,7 +18,7 @@ for files in `echo $@`; do
files=`echo $files | grep "\.php$"`
if [ -n "$files" ]; then
# Requires trough new call:
- j=`cat $files | grep -i new | egrep "(=|return)" | egrep -v "^[[:space:]*]*(\/\/|#|\*|/\*)" | tr -d "\r" | egrep "[;|(|)|{|}|,][[:space:]*]*$" | awk -F "new " '{ print $2 }' | sed "s/[(|;|.]/ /g" | cut -f 1 -d " " | sed "s/^$.*//"`
+ j=`cat $files | grep -i new | grep -E "(=|return)" | grep -E -v "^[[:space:]*]*(\/\/|#|\*|/\*)" | tr -d "\r" | grep -E "[;|(|)|{|}|,][[:space:]*]*$" | awk -F "new " '{ print $2 }' | sed "s/[(|;|.]/ /g" | cut -f 1 -d " " | sed "s/^$.*//"`
if [ -n "$j" ]; then
for feature in $j; do
echo "pear($feature)"
@@ -26,7 +26,7 @@ for files in `echo $@`; do
j=""
fi
# requires trough class extension
- k=`cat $files | egrep -i "(^Class.*extends)" | awk -F " extends " '{ print $2 }' | sed "s/{.*/ /" | cut -f 1 -d " " | tr -d "\r"`
+ k=`cat $files | grep -E -i "(^Class.*extends)" | awk -F " extends " '{ print $2 }' | sed "s/{.*/ /" | cut -f 1 -d " " | tr -d "\r"`
if [ -n "$k" ]; then
for feature in $k; do
echo "pear($feature)"
@@ -34,7 +34,7 @@ for files in `echo $@`; do
k=""
fi
# requires trough class:: call
- l=`cat $files | grep "::" | egrep -v "^[[:space:]*]*(\/\/|#|\*|/\*)" | sed "s/[(|'|!|\"|&|@|;]/ /g" | awk -F "::" '{ print $1 }' | sed "s/.*\ \([:alphanum:]*\)/\1/" | sed "s/^$.*//" | sed "s/[.]//g" | tr -d "\r"`
+ l=`cat $files | grep "::" | grep -E -v "^[[:space:]*]*(\/\/|#|\*|/\*)" | sed "s/[(|'|!|\"|&|@|;]/ /g" | awk -F "::" '{ print $1 }' | sed "s/.*\ \([:alphanum:]*\)/\1/" | sed "s/^$.*//" | sed "s/[.]//g" | tr -d "\r"`
if [ -n "$l" ]; then
for feature in $l; do
echo "pear($feature)"
diff --git a/scripts/mono-find-provides b/scripts/mono-find-provides
index 2c808a038..9348457d3 100644
--- a/scripts/mono-find-provides
+++ b/scripts/mono-find-provides
@@ -11,7 +11,7 @@
IFS=$'\n'
filelist=($(grep -Ev '/usr/doc/|/usr/share/doc/'))
-monolist=($(printf "%s\n" "${filelist[@]}" | egrep "\\.(exe|dll)\$"))
+monolist=($(printf "%s\n" "${filelist[@]}" | grep -E "\\.(exe|dll)\$"))
# If monodis is in the package being installed, use that one
# This is to support building mono
diff --git a/scripts/mono-find-requires b/scripts/mono-find-requires
index 66b1f4bc7..ea58cae48 100644
--- a/scripts/mono-find-requires
+++ b/scripts/mono-find-requires
@@ -11,7 +11,7 @@
IFS=$'\n'
filelist=($(grep -Ev '/usr/doc/|/usr/share/doc/'))
-monolist=($(printf "%s\n" "${filelist[@]}" | egrep "\\.(exe|dll)\$"))
+monolist=($(printf "%s\n" "${filelist[@]}" | grep -E "\\.(exe|dll)\$"))
# If monodis is in the package being installed, use that one
# This is to support building mono
diff --git a/scripts/find-debuginfo.sh b/scripts/find-debuginfo.sh
index 8d86de67e..01456dabc 100644
--- a/scripts/find-debuginfo.sh
+++ b/scripts/find-debuginfo.sh
@@ -16,7 +16,7 @@
# A -o switch that follows a -p switch or some -l switches produces
# an additional output file with the debuginfo for the files in
# the -l filelist file, or whose names match the -p pattern.
# The -p argument is an egrep-style regexp matching the a file name,
# and must not use anchors (^ or $).
#
# All file names in switches are relative to builddir (. if not given).
@@ -246,7 +246,7 @@ done
if [ -s "$SOURCEFILE" ]; then
mkdir -p "${RPM_BUILD_ROOT}/usr/src/debug"
- LC_ALL=C sort -z -u "$SOURCEFILE" | egrep -v -z '(<internal>|<built-in>)$' |
+ LC_ALL=C sort -z -u "$SOURCEFILE" | grep -E -v -z '(<internal>|<built-in>)$' |
(cd "$RPM_BUILD_DIR"; cpio -pd0mL "${RPM_BUILD_ROOT}/usr/src/debug")
# stupid cpio creates new directories in mode 0700, fixup
find "${RPM_BUILD_ROOT}/usr/src/debug" -type d -print0 |
@@ -268,7 +268,7 @@ fi
# Append to $1 only the lines from stdin not already in the file.
append_uniq()
{
- fgrep -f "$1" -x -v >> "$1"
+ grep -F -f "$1" -x -v >> "$1"
}
# Helper to generate list of corresponding .debug files from a file list.
@@ -288,7 +288,7 @@ filtered_list()
local out="$1"
shift
test $# -gt 0 || return
- fgrep -f <(filelist_debugfiles 's,^.*$,/usr/lib/debug&.debug,' "$@") \
+ grep -F -f <(filelist_debugfiles 's,^.*$,/usr/lib/debug&.debug,' "$@") \
-x $LISTFILE >> $out
sed -n -f <(filelist_debugfiles 's/[\\.*+#]/\\&/g
h
@@ -298,12 +298,12 @@ s,^.*$,s# /usr/lib/debug&.debug$##p,p
' "$@") "$LINKSFILE" | append_uniq "$out"
}
# Write an output debuginfo file list based on an egrep-style regexp.
pattern_list()
{
local out="$1" ptn="$2"
test -n "$ptn" || return
- egrep -x -e "$ptn" "$LISTFILE" >> "$out"
+ grep -E -x -e "$ptn" "$LISTFILE" >> "$out"
sed -n -r "\#^$ptn #s/ .*\$//p" "$LINKSFILE" | append_uniq "$out"
}
@@ -315,7 +315,7 @@ while ((i < nout)); do
> ${outs[$i]}
filtered_list ${outs[$i]} ${lists[$i]}
pattern_list ${outs[$i]} "${ptns[$i]}"
- fgrep -vx -f ${outs[$i]} "$LISTFILE" > "${LISTFILE}.new"
+ grep -Fvx -f ${outs[$i]} "$LISTFILE" > "${LISTFILE}.new"
mv "${LISTFILE}.new" "$LISTFILE"
((++i))
done
@@ -16,7 +16,7 @@
# an additional output file with the debuginfo for the files in
# the -l filelist file, or whose names match the -p pattern.
-# The -p argument is an egrep-style regexp matching the a file name,
+# The -p argument is an grep -E -style regexp matching the a file name,
# and must not use anchors (^ or $).
#
@@ -298,12 +298,12 @@ s,^.*$,s# /usr/lib/debug&.debug$##p,p
' "$@") "$LINKSFILE" | append_uniq "$out"
}
-# Write an output debuginfo file list based on an egrep-style regexp.
+# Write an output debuginfo file list based on an grep -E -style regexp.
pattern_list()
{
diff --git a/scripts/vpkg-provides.sh b/scripts/vpkg-provides.sh
index b0fbf18f1..78f24b82b 100755
--- a/scripts/vpkg-provides.sh
+++ b/scripts/vpkg-provides.sh
@@ -49,7 +49,7 @@
usage="usage: $0 --spec_header '/path/to/os-base-header.spec' \n"
usage="$usage\t[--find_provides '/path/to/find-provides']\n"
usage="$usage\t[--shlib_dirs 'dirs:which:contain:shared:libs']\n"
-usage="$usage\t[--ignore_dirs 'egrep|pattern|of|paths|to|ignore']\n"
+usage="$usage\t[--ignore_dirs 'grep-E|pattern|of|paths|to|ignore']\n"
# these two should be unnessary as the regular dependency analysis
# should take care of interpreters as well as shared libraries.
@@ -70,7 +70,7 @@ hostname=`uname -n`
# if some subdirectories of the system directories needs to be ignored
# (eg /usr/local is a subdirectory of /usr but should not be part of
# the virtual package) then call this script with ignore_dirs set to a
# vaild egrep pattern which discribes the directories to ignored.
PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/ucb:/usr/bsd
export PATH
@@ -244,7 +244,7 @@ fi
#
for d in `echo $shlib_dirs | sed -e 's/:/ /g'`
do
- find $d -type f -print 2>/dev/null | egrep -v \'$ignore_dirs\' | $find_provides >> $provides_tmp
+ find $d -type f -print 2>/dev/null | grep -E -v \'$ignore_dirs\' | $find_provides >> $provides_tmp
done
sum_tmp=/tmp/sum.$$
@@ -258,7 +258,7 @@ fi
#
for d in `echo $shlib_dirs | sed -e 's/:/ /g'`
do
- find $d -type f -print 2>/dev/null | egrep -v \'$ignore_dirs\' | $sum_cmd >> $sum_tmp
+ find $d -type f -print 2>/dev/null | grep -E -v \'$ignore_dirs\' | $sum_cmd >> $sum_tmp
done
@@ -361,7 +361,7 @@ fi
for d in `echo $shlib_dirs | sed -e 's/:/ /g'`
do
- find \$d -type f -print 2>/dev/null | egrep -v \'$ignore_dirs\' | $sum_cmd >> \$sum_current_tmp
+ find \$d -type f -print 2>/dev/null | grep -E -v \'$ignore_dirs\' | $sum_cmd >> \$sum_current_tmp
done
cat >\$sum_package_tmp <<_EOF_
@@ -70,7 +70,7 @@ hostname=`uname -n`
# (eg /usr/local is a subdirectory of /usr but should not be part of
# the virtual package) then call this script with ignore_dirs set to a
-# vaild egrep pattern which discribes the directories to ignored.
+# valid grep -E pattern which discribes the directories to ignored.
PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/ucb:/usr/bsd
export PATH